@@ -1,6 +1,6 @@
-#define G_INLINE_FUNC
 #include <X11/Xlib.h>
 #include <stdio.h>
+#include <stdlib.h>
 
 #ifdef HAVE_CONFIG_H
 #  include "../../../config.h"
@@ -58,7 +58,7 @@ static int iwtroz;           /* direction of frame */
 static int lclatrz;          /* type of screen */
 static int wsxwd, wsywd, wsxmnz, wsxmxz, wsymnz, wsymxz;
 static int ixz, iyz, iwz, ihz, ixxz, iyyz, page; /* for image */
-static int posx, posy, wait, wait0, wait1, key, dump, fgbg;
+static int posx, posy, wait_np, wait_op, wait_cl, key, dump, fgbg;
 static int nbmap, nn1[MAXBMP], nn2[MAXBMP], nx[MAXBMP], ny[MAXBMP];
 static char dmpfile[80], xtitle[80];
 static char bmline[MAXBMP][260];
@@ -67,6 +67,7 @@ static int lfirst = TRUE;
 
 static GdkGC *gc;
 static GdkGC *gct;
+static GtkWidget *window = NULL;
 static GtkWidget *drawing_area = NULL;
 static GdkPixmap *pixmap = NULL;
 
@@ -154,7 +155,7 @@ gint zg_key_press_event(widget, event)
       break;
     case GDK_s:
       next = TRUE;
-      wait = FALSE;
+      wait_np = FALSE;
       break;
     case GDK_q:
       gtk_exit(0);
@@ -195,7 +196,6 @@ GtkWidget * zggdrw_(width, height)
      int *width, *height;
 {
   GtkWidget * drw;
-  GtkWidget *window;
   GtkWidget *vbox;
 
   wsxwd  = *width  + 2 * PAD;  /* window width */
@@ -306,6 +306,8 @@ void zgdopn_(width, height, iposx, iposy, lwait, lwait0, lwait1,
      int *lkey, *ldump, *lwnd, *lfgbg;
      char cimgfmt[], clrmap[], cbmmap[], file[], title[];
 {
+  void cfnchr();
+
 #ifdef HAVE_GTK_H
   int ncolor, n, m;
 
@@ -322,9 +324,9 @@ void zgdopn_(width, height, iposx, iposy, lwait, lwait0, lwait1,
 
   posx      = *iposx;
   posy      = *iposy;
-  wait      = *lwait;
-  wait0     = *lwait0;
-  wait1     = *lwait1;
+  wait_np   = *lwait;
+  wait_op   = *lwait0;
+  wait_cl   = *lwait1;
   key       = *lkey;
   dump      = *ldump;
   fgbg      = *lfgbg;
@@ -333,10 +335,10 @@ void zgdopn_(width, height, iposx, iposy, lwait, lwait0, lwait1,
   wnd       = *lwnd;
   cfnchr(imgfmt, cimgfmt, 7);
   if (!wnd) {
-    wait  = FALSE;
-    wait0 = FALSE;
-    wait1 = FALSE;
-    dump  = TRUE;
+    wait_np = FALSE;
+    wait_op = FALSE;
+    wait_cl = FALSE;
+    dump    = TRUE;
   }
 #else
   wnd       = TRUE;
@@ -368,6 +370,7 @@ void zgdopn_(width, height, iposx, iposy, lwait, lwait0, lwait1,
   fscanf(stream, "%d : %s", &ncolor, c);
   for (n = 0; n < ncolor; n++)
     fscanf(stream, "%6hd%6hd%6hd : %s", &rx[n], &gx[n], &bx[n], c);
+  fclose(stream);
 
   if (fgbg) {
     rx1 = rx[0];
@@ -396,6 +399,7 @@ void zgdopn_(width, height, iposx, iposy, lwait, lwait0, lwait1,
   for (n = 0; n < nbmap; n++)
     fscanf(stream, "%4d%4d%3d%3d%s",
 	   &nn1[n], &nn2[n], &nx[n], &ny[n], bmline[n]);
+  fclose(stream);
 
   /* set colormap */
 
@@ -448,7 +452,7 @@ void zgdopn_(width, height, iposx, iposy, lwait, lwait0, lwait1,
 
     zgupdate();
 
-    if (wait0) {
+    if (wait_op) {
       next = FALSE;
       ifunc = DOPN;
       while (1) {
@@ -470,12 +474,13 @@ void zgdcls_()
   /* device closing proc. */
 
   GdkEvent *ev;
+  printf("cls\n");
 
   if (ldclonly) {
 
     zgupdate();
 
-    if (!wait && wait1) {
+    if (!wait_np && wait_cl) {
       next = FALSE;
       ifunc = DCLS;
       while (1) {
@@ -484,6 +489,12 @@ void zgdcls_()
 	  break;
       }
     }
+
+    gtk_widget_destroy(drawing_area);
+    drawing_area = NULL;
+    gtk_widget_destroy(window);
+    window = NULL;
+
   }
 #endif
 }
@@ -522,7 +533,7 @@ void zgpcls_()
 
     zgupdate();
 
-    if (wait) {
+    if (wait_np) {
       dumpz = FALSE;
       next = FALSE;
       ifunc = PCLS;
@@ -613,8 +624,8 @@ void zgscli_(iclidx)
 
   iclidz = *iclidx % MAXCLI;
 
-  if (iclidz == 0)
-    iclidz = 1;
+/*if (iclidz == 0)
+    iclidz = 1; */
 #endif
 }
 
@@ -704,8 +715,8 @@ void zggton_(np, wpx, wpy, itpat)
 
   ibit = *itpat % 1000;
   iclr = (*itpat / 1000) % MAXCLI;
-  if (iclr == 0)
-    iclr = 1;
+/*if (iclr == 0)
+    iclr = 1; */
 
   gdk_gc_set_foreground (gct, &cx[iclr]);
 
